API docs for “spamfighter.interfaces.IPartner”

# Class s.i.IPartner(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Партнер - единица авторизации относительно API веб-сервиса СпамоБорца. Партнер - это единица аккаунтинга запросов (кол-во запросов в сутки или за другой отчетный период). Партнер - это единица отслеживания любой финансовой информации.

Партнер содержит ссылку на корневой домен партнера, ограничивая видимое пространство доменов.

Method | rootDomain | Получить корневой домен партнера.

def rootDomain(): (source)
Получить корневой домен партнера.

Returns | Deferred, корневой домен (`IDomain`) (type: `twisted.internet.defer.Deferred` )